@@ -4,7 +4,8 @@
 openEditRecord = function() {
     var $registryRow = $(this).closest('tr');
     var objectID = $registryRow.attr("objectid");
-    var icon = $(this).find( "i" ).attr("class");
+    var editBtn = $(this).find( "i" )
+    var icon = $(editBtn).attr("class");
 
     // Show loading spinner
     showSpinner($(this).find("i"))
@@ -19,13 +20,12 @@ openEditRecord = function() {
             window.location = data.url;
         },
         error:function(data){
-
-            var myArr = JSON.parse(data.responseText);
-            $.notify(myArr.message, {style: myArr.tags });
+            let jsonResponse = JSON.parse(data.responseText);
+            $.notify(jsonResponse.message, "danger");
         }
     }).always(function() {
         // get old button icon
-        hideSpinner($(this).find("i"), icon)
+        hideSpinner(editBtn, icon)
     });
 };
 
