@@ -29,6 +29,7 @@ from core_main_app.commons.exceptions import (
 )
 from core_main_app.components.blob import api as blob_api
 from core_main_app.components.lock import api as lock_api
+from core_main_app.components.template.models import Template
 from core_main_app.components.workspace import api as workspace_api
 from core_main_app.settings import INSTALLED_APPS
 from core_main_app.utils.labels import get_data_label, get_form_label
@@ -162,7 +163,6 @@ def _get_data(data_ids, user):
     data_table = []
     try:
         for data_id in data_ids:
-
             # Get the data
             data = data_api.get_by_id(data_id, user)
 
@@ -199,7 +199,6 @@ def _get_query(query_type, query_ids, user):
     query_table = []
     try:
         for query_id in query_ids:
-
             # Get the persistent query
             query = persistent_query_api.get_by_id(query_type, query_id, user)
 
@@ -602,7 +601,16 @@ def edit_record(request):
             json.dumps({"message": message.message, "tags": message.tags}),
             content_type="application/json",
         )
-
+    # Check if XSD format data
+    if data.template.format != Template.XSD:
+        message = Message(
+            messages.ERROR,
+            f"Unable to edit  {get_data_label()}. This feature is only available for XML {get_data_label()} ",
+        )
+        return HttpResponseBadRequest(
+            json.dumps({"message": message.message, "tags": message.tags}),
+            content_type="application/json",
+        )
     try:
         # Check if a curate data structure already exists
         curate_data_structure = (
@@ -629,7 +637,7 @@ def edit_record(request):
             user=str(request.user.id),
             template=template,
             name=data.title,
-            form_string=data.xml_content,
+            form_string=data.content,
             data=data,
         )
         try:
